@@ -171,7 +171,10 @@ class Game (object):
 
     def __new__(cls, eid=None, fpath=None):
         # If we can't get a valid JSON data, exit out and return None.
-        rawData = _get_json_data(eid, fpath)
+        try:
+            rawData = _get_json_data(eid, fpath)
+        except urllib2.URLError:
+            return None
         if rawData is None or rawData.strip() == '{}':
             return None
         game = object.__new__(cls)
@@ -295,6 +298,9 @@ class Game (object):
     def __sub__(self, other):
         return diff(other, self)
 
+    def __str__(self):
+        return self.nice_score()
+
 
 def diff(before, after):
     """
@@ -424,6 +430,10 @@ class Drive (object):
         new_drive.time_end = None
         return new_drive
 
+    def __str__(self):
+        return '%s (Start: %s, End: %s) %s' \
+               % (self.team, self.time_start, self.time_end, self.result)
+
 
 class Play (object):
     """
@@ -436,9 +446,11 @@ class Play (object):
     play was a first down, a fourth down failure, etc.
     """
     def __init__(self, drive, playid, data):
+        self.data = data
         self.drive = drive
         self.playid = playid
         self.team = data['posteam']
+        self.home = self.drive.home
         self.desc = data['desc']
         self.note = data['note']
         self.down = int(data['down'])
@@ -461,14 +473,37 @@ class Play (object):
                                                   info['yards'])
                 for k, v in statvals.iteritems():
                     self.__dict__[k] = self.__dict__.get(k, 0) + v
+
+        # Load the sequence of "events" in a play into a list of dictionaries.
+        self.events = _json_play_events(data['players'])
+
+        # Now load cumulative player data for this play into
+        # a GenPlayerStats generator. We then flatten this data
+        # and add it to the play itself so that plays can be
+        # filter by these statistics.
         self.__players = _json_play_players(self, data['players'])
         self.players = nflgame.seq.GenPlayerStats(self.__players)
+        for p in self.players:
+            for k, v in p.stats.iteritems():
+                # Sometimes we may see duplicate statistics (like tackle
+                # assists). Let's just overwrite in this case, since this
+                # data is from the perspective of the play. i.e., there
+                # is one assisted tackle rather than two.
+                self.__dict__[k] = v
 
     def has_player(self, playerid):
         """Whether a player with id playerid participated in this play."""
         return playerid in self.__players
 
     def __str__(self):
+        if self.team:
+            if self.down != 0:
+                return '(%s, %s, %d and %d) %s' \
+                       % (self.team, self.data['yrdln'],
+                          self.down, self.yards_togo, self.desc)
+            else:
+                return '(%s, %s) %s' \
+                       % (self.team, self.data['yrdln'], self.desc)
         return self.desc
 
     def __eq__(self, other):
@@ -478,6 +513,9 @@ class Play (object):
         """
         return self.playid == other.playid and self.desc == other.desc
 
+    def __getattr__(self, name):
+        return 0
+
 
 def _json_team_stats(data):
     """
@@ -560,6 +598,23 @@ def _json_play_players(play, data):
     return players
 
 
+def _json_play_events(data):
+    """
+    Takes a single JSON play entry (data) and converts it to a list of events.
+    """
+    temp = list()
+    for playerid, statcats in data.iteritems():
+        for info in statcats:
+            if info['statId'] not in nflgame.statmap.idmap:
+                continue
+            statvals = nflgame.statmap.values(info['statId'], info['yards'])
+            statvals['playerid'] = None if playerid == '0' else playerid
+            statvals['playername'] = info['playerName'] or None
+            statvals['team'] = info['clubcode']
+            temp.append((int(info['sequence']), statvals))
+    return [t[1] for t in sorted(temp, key=lambda t: t[0])]
+
+
 def _json_game_player_stats(data):
     """
     Parses the 'home' and 'away' team stats and returns an OrderedDict
