@@ -56,6 +56,26 @@ class Player (object):
                             list(g.drives.plays()))
         return nflgame.seq.GenPlays(plays)
 
+    def __str__(self):
+        return '%s (%s, %s)' % (self.name, self.position, self.team)
+
+
+class PlayerDefense (Player):
+    def __init__(self, team):
+        self.playerid = None
+        self.name = team
+        self.team = team
+        self.position = 'DEF'
+
+    def stats(self, year, week=None):
+        assert False, 'Cannot be called on a defense.'
+
+    def plays(self, year, week=None):
+        assert False, 'Cannot be called on a defense.'
+
+    def __str__(self):
+        return '%s Defense' % self.team
+
 
 class PlayerStats (object):
     """
@@ -84,9 +104,12 @@ class PlayerStats (object):
         player is playing in a home game or not.
         """
         self.playerid = playerid
+        self.player = None
         self.name = name
         self.home = home
         self._stats = OrderedDict()
+        if self.playerid in nflgame.players:
+            self.player = nflgame.players[self.playerid]
 
     def has_cat(self, cat):
         return self.__dict__.get(cat, False)
@@ -168,6 +191,9 @@ class PlayerStats (object):
         new_player = GamePlayerStats(self.playerid, self.name, self.home)
         new_player._add_stats(self._stats)
         for bk, bv in other._stats.iteritems():
+            if bk not in new_player._stats:  # stat was taken away? ignore.
+                continue
+
             new_player._stats[bk] -= bv
             if new_player._stats[bk] == 0:
                 del new_player._stats[bk]
